Feedforward Closedloop Learning: Class List

Feedforward Closedloop Learning

Class List
Here are the classes, structs, unions and interfaces with brief descriptions:
[detail level 12]

▼Nfeedforward_closedloop_learning |
C _SwigNonDynamicMeta |
C CalcOutputThread |
C FeedforwardClosedloopLearning |
C FeedforwardClosedloopLearningWithFilterbank |
C Layer |
C LayerThread |
C LearningThread |
C MaxDetThread |
C Neuron |
C Bandpass | Creates memory traces at specified length
C FeedforwardClosedloopLearning | Main class of Feedforward Closed Loop Learning
C FeedforwardClosedloopLearningWithFilterbank | Derived classes of the FeedforwardClosedloopLearning class for special functionality
C Layer | Layer which contains the neurons of one layer
C Neuron | Neuron which calculates the output and performs learning